@@ -4,7 +4,7 @@
 
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
-       jabber: rafim@jabber.org
+       jabber: rafim@jabber.airm.net
     home page: http://smbc.airm.net
   
     last update: 2004-06-02
@@ -32,6 +32,7 @@
 #include "rtypedef.h"
 #include "bookmarks.h"
 #include "convert.h"
+#include "convertm.h"
 #include "fnet.h"
 
 #define _(String) gettext (String)
@@ -153,12 +154,12 @@ RaddToBookmark(TTbookmark **Rbk, int Riselect, char *Riagroup, char *Riahost, ch
   (*Rbk)->next = NULL;
   (*Rbk)->type = Riselect;
   (*Rbk)->del = 'X';
-  strcpy((*Rbk)->username, Riusername);
-  strcpy((*Rbk)->password, Ripassword);
-  strcpy((*Rbk)->group, Riagroup);
-  strcpy((*Rbk)->host, Riahost);
-  strcpy((*Rbk)->dir, Riadir);
-  strcpy((*Rbk)->file, Rifile);
+  Rstrcpy((*Rbk)->username, RMAXGHLEN, Riusername, -1);
+  Rstrcpy((*Rbk)->password, RMAXGHLEN, Ripassword, -1);
+  Rstrcpy((*Rbk)->group, RMAXGHLEN, Riagroup, -1);
+  Rstrcpy((*Rbk)->host, RMAXGHLEN, Riahost, -1);
+  Rstrcpy((*Rbk)->dir, TTBOOKMARKDIRLEN, Riadir, -1);
+  Rstrcpy((*Rbk)->file, TTBOOKMARKFILELEN, Rifile, -1);
 }
 
 void 
@@ -172,7 +173,7 @@ RopenBookmark(TTbookmark **Rbk, char *RfileName)
   if (*Rbk != NULL)
     return;
  
-  Rfhandle = open(RfileName, O_RDONLY, 0644);
+  Rfhandle = open(to_sys(RfileName), O_RDONLY, 0644);
   if (Rfhandle > 0) 
   {
     RDBG("bookmarks RopenBookmark Rfhandle > 0\n");
@@ -207,8 +208,8 @@ RsaveBookmark(TTbookmark *Rbk, char *RfileName)
 
   RDBG("bookmarks RsaveBookmark start\n");
   RgotoFirstBookmark(&Rbk);
-  unlink(RfileName);
-  Rfhandle = open(RfileName, O_CREAT | O_NONBLOCK | O_WRONLY | O_TRUNC, 0644);
+  unlink(to_sys(RfileName));
+  Rfhandle = open(to_sys(RfileName), O_CREAT | O_NONBLOCK | O_WRONLY | O_TRUNC, 0644);
   if (Rfhandle > 0) 
   {
     RDBG("bookmarks RsaveBookmark Rfhandle > 0\n");
