@@ -4,7 +4,7 @@
 
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
-       jabber: rafim@jabber.org
+       jabber: rafim@jabber.airm.net
     home page: http://smbc.airm.net
   
     last update: 2004-05-26
@@ -13,13 +13,16 @@
 #include "../config.h"
 #include "consts.h"
 
+#define TTBOOKMARKDIRLEN 2000
+#define TTBOOKMARKFILELEN 1000
+
 typedef struct Tbookmark { 
   char username[RMAXGHLEN];
   char password[RMAXGHLEN];
   char group[RMAXGHLEN];
   char host[RMAXGHLEN];
-  char dir[2000];
-  char file[1000];
+  char dir[TTBOOKMARKDIRLEN];
+  char file[TTBOOKMARKFILELEN];
   char type;
   char del;
   struct Tbookmark *next;
