@@ -4,7 +4,7 @@
 
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
-       jabber: rafim@jabber.org
+       jabber: rafim@jabber.airm.net
     home page: http://smbc.airm.net
   
     last update: 2004-03-01
