@@ -48,18 +48,24 @@ RdoneIconv()
 char *
 to_scr(char *str)
 {
+  if (str == NULL)
+    return(NULL);
   return (char *)iconv_convert(iconv_utf_to_screen, str);
 }
 
 char *
 to_sys(char *str)
 {
+  if (str == NULL)
+    return(NULL);
   return (char *)iconv_convert(iconv_utf_to_system, str);
 }
 
 char *
 from_sys(char *str)
 {
+  if (str == NULL)
+    return(NULL);
   return (char *)iconv_convert(iconv_system_to_utf, str);
 }
 
