@@ -4,10 +4,8 @@
 
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
-       jabber: rafim@jabber.org
+       jabber: rafim@jabber.airm.net
     home page: http://smbc.airm.net
-  
-    last update: 2004-08-06
 */
 
 #include "../config.h"
