@@ -4,10 +4,8 @@
 
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
-       jabber: rafim@jabber.org
+       jabber: rafim@jabber.airm.net
     home page: http://smbc.airm.net
-  
-    last update: 2004-07-27
 */
 
 #define _GNU_SOURCE
@@ -32,6 +30,7 @@
 #include "debug.h"
 #include "rtypedef.h"
 #include "convertm.h"
+#include "downloadlist.h"
 
 #define _(String) gettext (String)
 #define gettext_noop(String) String
@@ -62,8 +61,10 @@ RlistAllDownloadLists()
   struct dirent *Rsdirent;
   int Rcount = 0;
 
-  asprintf(&Rdir, "%s/.smbc/", getenv("HOME"));
-  Rdhandle = opendir(Rdir);
+  Rasprintf(&Rdir, getenv("HOME"));
+  Rstraddtoend(&Rdir, "/.smbc/");
+
+  Rdhandle = opendir(to_sys(Rdir));
   if (Rdhandle != NULL) 
   { 
     while ((Rsdirent = readdir(Rdhandle)) > 0) 
@@ -77,7 +78,7 @@ RlistAllDownloadLists()
     }
     closedir(Rdhandle);
   }
-  free(Rdir);
+  Rfree(Rdir);
   printf(_("Founded %i lists\n"), Rcount);
 }
 
@@ -93,7 +94,7 @@ RflushAllDownloadLists()
   asprintf(&Rdir, "%s/.smbc/", getenv("HOME"));
   RfindF = 1;
   while (RfindF) {
-    Rdhandle = opendir(Rdir);
+    Rdhandle = opendir(to_sys(Rdir));
     if (Rdhandle != NULL) 
     { 
       RfindF = 0;
@@ -104,8 +105,8 @@ RflushAllDownloadLists()
           {
             asprintf(&RdufileName, "%s/.smbc/%s", getenv("HOME"),Rsdirent->d_name);
             printf(_("%s flushed\n"), Rsdirent->d_name); 
-            unlink(RdufileName);
-            free(RdufileName);
+            unlink(to_sys(RdufileName));
+            Rfree(RdufileName);
             RfindF = 1;
           }       
       }
@@ -114,7 +115,7 @@ RflushAllDownloadLists()
       RfindF = 0;
     closedir(Rdhandle);
   }
-  free(Rdir);
+  Rfree(Rdir);
   printf(_("Flush done.\n"));
 }
 
@@ -144,9 +145,10 @@ RShowAllItemsFromDUlist(int RnrDulist)
   int Rfhandle;
   TTdownload *Rdls;
   char *RstrT;
+  int Ri;
 
   asprintf(&RdufileName, "%s/.smbc/dulist%i", getenv("HOME"), RnrDulist);
-  Rfhandle = open(RdufileName, O_NONBLOCK | O_RDONLY, 0755);
+  Rfhandle = open(to_sys(RdufileName), O_NONBLOCK | O_RDONLY, 0755);
   if (Rfhandle > 0) {
     printf("---------------------------------------------------------\n");
     printf(" 1 | 2 | 3 | 4 | 5 | 6 | 7\n\n");
@@ -158,25 +160,55 @@ RShowAllItemsFromDUlist(int RnrDulist)
     printf(_("6 - 'D' - download, 'U' - upload\n"));
     printf(_("7 - remote path\n"));
     printf("---------------------------------------------------------\n");
-    Rdls = malloc(RdlsSize); 
-    while (read(Rfhandle, Rdls, RdlsSize) == RdlsSize) 
+    Ri = 0;
+    while (Ri != -1)
     {
-      asprintf(&RstrT, "%s | %s | %s | %s | %c | %c | %s/%s\n", \
-         Rdls->pathL, \
-         Rdls->groupnameR, \
-         Rdls->sizeDisplayR, \
-         Rdls->percent, \
-         Rdls->active, \
-         Rdls->upload, \
-         Rdls->pathR, \
-         Rdls->filename);
-      printf(to_scr(RstrT));
-      free(RstrT);
+      Rdls = RcreateEmptyTTdownload();
+      
+      Ri = RreadStr(Rfhandle, &(Rdls->username));
+      if (Ri != -1) Ri = RreadStr(Rfhandle, &(Rdls->password));
+      if (Ri != -1) Ri = RreadStr(Rfhandle, &(Rdls->groupnameR));
+      if (Ri != -1) Ri = RreadStr(Rfhandle, &(Rdls->pathRLbase));
+      if (Ri != -1) Ri = RreadStr(Rfhandle, &(Rdls->pathR));
+      if (Ri != -1) Ri = RreadStr(Rfhandle, &(Rdls->pathL));
+      if (Ri != -1) Ri = RreadStr(Rfhandle, &(Rdls->fullfilename));
+      if (Ri != -1) Ri = RreadStr(Rfhandle, &(Rdls->filename));
+      if (Ri != -1) Ri = RreadUnsignedInt(Rfhandle, &(Rdls->sizeR));
+      if (Ri != -1) Ri = RreadStr(Rfhandle, &(Rdls->sizeDisplayR));
+      if (Ri != -1) Ri = RreadStr(Rfhandle, &(Rdls->sizeDisplayDownR));
+      if (Ri != -1) Ri = RreadStr(Rfhandle, &(Rdls->percent));
+      if (Ri != -1) Ri = RreadChar(Rfhandle, &(Rdls->active));
+      if (Ri != -1) Ri = RreadChar(Rfhandle, &(Rdls->upload));
+      if (Ri != -1) Ri = RreadTime_t(Rfhandle, &(Rdls->delayRetry));
+      if (Ri != -1) Ri = RreadTime_t(Rfhandle, &(Rdls->nextRetry));
+
+      if (Ri != -1)
+      {
+        Rstraddtoend(&RstrT, Rdls->pathL);
+        Rstraddtoend(&RstrT, " | ");
+        Rstraddtoend(&RstrT, Rdls->groupnameR);
+        Rstraddtoend(&RstrT, " | ");
+        Rstraddtoend(&RstrT, Rdls->sizeDisplayR);
+        Rstraddtoend(&RstrT, " | ");
+        Rstraddtoend(&RstrT, Rdls->percent);
+        Rstraddtoend(&RstrT, " | ");
+        Rcharaddtoend(&RstrT, Rdls->active);
+        Rstraddtoend(&RstrT, " | ");
+        Rcharaddtoend(&RstrT, Rdls->upload);
+        Rstraddtoend(&RstrT, " | ");
+        Rstraddtoend(&RstrT, Rdls->pathR);
+        Rstraddtoend(&RstrT, "/");
+        Rstraddtoend(&RstrT, Rdls->filename);
+        Rstraddtoend(&RstrT, "\n");
+        printf(to_scr(RstrT));
+        Rfree(RstrT);
+        RfreeOneTTdownloadAndGoToFirst(&Rdls);
+      }
     }
     close(Rfhandle);
     realloc(Rdls, RdlsSize);
   }
-  free(RdufileName);
+  Rfree(RdufileName);
 }
 
 int 
@@ -193,12 +225,15 @@ RsaveMessage(char *Rstr, char *RfileName)
 
   umask(0000);
   mkdir(RMESSAGEDIR, 0777);
-  if ((Rfi = open(RfileName, O_RDONLY)) > 0) 
+  if ((Rfi = open(to_sys(RfileName), O_RDONLY)) > 0) 
   {
     while (Rfinding) 
     {
-      asprintf(&Rfile, "%s/%s%i", RMESSAGEDIR, RMESSAGEFILE, Ri);
-      if ((Rf = open(Rfile, O_CREAT | O_EXCL | O_WRONLY, 0666)) > 0) 
+      Rasprintf(&Rfile, RMESSAGEDIR);
+      Rcharaddtoend(&Rfile, '/');
+      Rstraddtoend(&Rfile, RMESSAGEFILE);
+      Rintaddtoend(&Rfile, Ri);
+      if ((Rf = open(to_sys(Rfile), O_CREAT | O_EXCL | O_WRONLY, 0666)) > 0) 
       {
         Rfinding = 0;
         write(Rf, Rstr, strlen(Rstr));
@@ -210,7 +245,7 @@ RsaveMessage(char *Rstr, char *RfileName)
       }
       else 
         Ri++;
-      free(Rfile);
+      Rfree(Rfile);
     }
   }
   return(1);
