@@ -4,10 +4,8 @@
 
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
-       jabber: rafim@jabber.org
+       jabber: rafim@jabber.airm.net
     home page: http://smbc.airm.net
-  
-    last update: 2004-03-10
 */
 #define _GNU_SOURCE
 #define READBF 1024
@@ -27,9 +25,11 @@
 #include <unistd.h>
 #include <libsmbclient.h>
 #include <stdlib.h>
+#include <math.h>
 #include "find-index-manage.h"
 #include "debug.h"
 #include "convert.h"
+#include "convertm.h"
 #include "fnet.h"
 
 TTfind *TfindRecord = NULL;
@@ -42,7 +42,7 @@ RmakeCopyFileWithPID(char *Rdst, char *Rsrc)
   int Rread;
 
   RDBG("find-index-manage: RmakeCopyFile start\n");
-  Rfdi = open(Rsrc, O_RDONLY);
+  Rfdi = open(to_sys(Rsrc), O_RDONLY);
   if (Rfdi <= 0) 
   {
     RDBG("find-index-manage: can't open ");
@@ -50,8 +50,7 @@ RmakeCopyFileWithPID(char *Rdst, char *Rsrc)
     RDBG(" file\n");
     return(0);
   }
-  //asprintf(&RfileName, "/tmp/smbc_%i_%i",  getuid(), getpid());
-  Rfdo = open(Rdst, O_CREAT | O_NONBLOCK | O_WRONLY | O_TRUNC, 0600);
+  Rfdo = open(to_sys(Rdst), O_CREAT | O_NONBLOCK | O_WRONLY | O_TRUNC, 0600);
   if (Rfdo <= 0) 
   {
     if (Rfdi > 0)
@@ -73,14 +72,14 @@ RindexFileUnlink(char *RpathToFile)
 {
   int Ri;
 
-  Ri = unlink(RpathToFile);
+  Ri = unlink(to_sys(RpathToFile));
   return(1);
 }
 
 int 
 RindexFileOpen(char *RpathToFile, int *RfileDesc)
 {
-  (*RfileDesc) = open(RpathToFile, O_RDONLY);
+  (*RfileDesc) = open(to_sys(RpathToFile), O_RDONLY);
   if ((*RfileDesc) > 0) {
     RDBG("find-index-manage: RindexFileInit exit ok\n");
     return(1);
@@ -100,60 +99,92 @@ RindexFileClose(int *RfileDesc)
 int 
 RindexFileCreate(char *RpathToFile, int *RfileDesc)
 {
-  (*RfileDesc) = open(RpathToFile, O_CREAT | O_NONBLOCK | O_RDWR | O_TRUNC, 0600);
+  (*RfileDesc) = open(to_sys(RpathToFile), O_CREAT | O_NONBLOCK | O_RDWR | O_TRUNC, 0600);
   if ((*RfileDesc) > 0)
     return(1);
   return(0);
 }
 
 int 
-RindexFileReadOneRecord(int RfileDesc, TTfind *TfindRecord)
+RindexFileReadOneRecord(int RfileDesc, TTfind **TfindRecord)
 {
   char Rc;
-  char Rstr[10240];
-  int Ri = 0;
+  char *Rstr = NULL;
   char *IIgroup = NULL;
   char *IIhost = NULL;
   char *IIpath = NULL;
+  char *IIfile = NULL;
 
+  *TfindRecord = NULL;
   while (read(RfileDesc, &Rc, 1) > 0) 
   {
     if (Rc)
-      Rstr[Ri++] = Rc;
-    else {
-      Rstr[Ri] = 0;
-      Ri = 0;
+    {
+      Rcharaddtoend(&Rstr, Rc);
+    }
+    else 
+    {
+      if (Rstr == NULL)
+        Rstr = Rstrdup("");
       if (IIgroup == NULL) 
-        asprintf(&IIgroup, "%s", Rstr);
+      {
+        IIgroup = Rstrdup(Rstr);
+        Rfree(Rstr);
+      }
       else 
+      {
         if (IIhost == NULL) 
-          asprintf(&IIhost, "%s", Rstr);
+        {
+          IIhost = Rstrdup(Rstr);
+          Rfree(Rstr);
+        }
         else 
+        {
           if (IIpath == NULL) 
-            asprintf(&IIpath, "%s", Rstr);
+          {
+            IIpath = Rstrdup(Rstr);
+            Rfree(Rstr);
+          }
           else 
           {
-            memcpy(TfindRecord->group, IIgroup, strlen(IIgroup)+1);
-            memcpy(TfindRecord->host, IIhost, strlen(IIhost)+1);
-            memcpy(TfindRecord->dir, IIpath, strlen(IIpath)+1);
-            memcpy(TfindRecord->file, Rstr, strlen(Rstr)+1);
-            if (IIgroup) 
-              free(IIgroup);
-            if (IIhost) 
-              free(IIhost);
-            if (IIpath) 
-              free(IIpath);
+            if (IIfile == NULL)
+            {
+              IIfile = Rstrdup(Rstr);
+              Rfree(Rstr);
+            }
+            else
+            {
+            *TfindRecord = Rmalloc(sizeof(TTfind));
+            (*TfindRecord)->group = Rstrdup(IIgroup);
+            (*TfindRecord)->host = Rstrdup(IIhost);
+            (*TfindRecord)->dir = Rstrdup(IIpath);
+            (*TfindRecord)->file = Rstrdup(IIfile);
+            (*TfindRecord)->access_denied = Rstrdup(Rstr);
+            RDBG("smbc: find-index-manage (*TfindRecord)->group = "); RDBG((*TfindRecord)->group); RDBG("\n");
+            RDBG("smbc: find-index-manage (*TfindRecord)->host = "); RDBG((*TfindRecord)->host); RDBG("\n");
+            RDBG("smbc: find-index-manage (*TfindRecord)->dir = "); RDBG((*TfindRecord)->dir); RDBG("\n");
+            RDBG("smbc: find-index-manage (*TfindRecord)->file = "); RDBG((*TfindRecord)->file); RDBG("\n");
+            RDBG("smbc: find-index-manage (*TfindRecord)->access_denied = "); RDBG((*TfindRecord)->access_denied); RDBG("\n");
+
+            Rfree(IIgroup);
+            Rfree(IIhost);
+            Rfree(IIpath);
+            Rfree(IIfile);
+            Rfree(Rstr);
+            //RDBG("find-index-manage: RindexFileReadOneRecord end 1\n");
             return(1);
+            }
           }
+        }
+      }
     }
   }
-  if (IIgroup) 
-    free(IIgroup);
-  if (IIhost) 
-    free(IIhost);
-  if (IIpath) 
-    free(IIpath);
-  //RDBG("\nfind-index-manage: RindexFileReadOneRecord return failed\n");
+  Rfree(IIgroup);
+  Rfree(IIhost);
+  Rfree(IIpath);
+  Rfree(IIfile);
+  Rfree(Rstr);
+  //RDBG("find-index-manage: RindexFileReadOneRecord end 0\n");
   return(0);
 }
 
@@ -164,6 +195,12 @@ RindexFileWriteOneRecord(int RfileDesc, TTfind *TfindRecord)
 
   if (RfileDesc > 0) 
   {
+    RDBG("smbc: RindexFileWriteOneRecord TfindRecord->group = "); RDBG(TfindRecord->group); RDBG("\n");
+    RDBG("smbc: RindexFileWriteOneRecord TfindRecord->host = "); RDBG(TfindRecord->host); RDBG("\n");
+    RDBG("smbc: RindexFileWriteOneRecord TfindRecord->dir = "); RDBG(TfindRecord->dir); RDBG("\n");
+    RDBG("smbc: RindexFileWriteOneRecord TfindRecord->file = "); RDBG(TfindRecord->file); RDBG("\n");
+    RDBG("smbc: RindexFileWriteOneRecord TfindRecord->access_denied = "); RDBG(TfindRecord->access_denied); RDBG("\n");
+    
     Ri = strlen(TfindRecord->group)+1; 
     if (write(RfileDesc, TfindRecord->group, Ri) != Ri)
       return(0);
@@ -176,6 +213,9 @@ RindexFileWriteOneRecord(int RfileDesc, TTfind *TfindRecord)
     Ri = strlen(TfindRecord->file)+1; 
     if (write(RfileDesc, TfindRecord->file, Ri) != Ri)
       return(0);
+    Ri = strlen(TfindRecord->access_denied)+1; 
+    if (write(RfileDesc, TfindRecord->access_denied, Ri) != Ri)
+      return(0);
   }
   return(1);
 }
@@ -185,45 +225,57 @@ RindexFileSetSeek(int RfileDesc, long int Rnr)
 {
   int Rt = 1;
   int Rcont = 1;
-  off_t Rseek;
-  TTfind TfindRecord;
+  TTfind *TfindRecord = NULL;
 
   RDBG("find-index-manage: RindexFileSetSeek start, try set ");
   RDBGi(Rnr); RDBG("\n");
-  Rseek = lseek(RfileDesc, 0, SEEK_SET);
+  // read counter
+  RindexFileReadCounter(RfileDesc);
+
   while (Rcont && (Rt < Rnr)) 
   {
     if (!RindexFileReadOneRecord(RfileDesc, &TfindRecord))
       Rcont = 0;
     Rt++;
+    RindexFreeOneTTfind(&TfindRecord);
   }
   if (Rt == Rnr) 
     return(1);
   return(0);
 }
 
+int 
+RindexFileExistAnyRecords(int RfileDesc)
+{
+  TTfind *TfindRecord = NULL;
+  
+  // read counter
+  RindexFileReadCounter(RfileDesc);
+
+  if (RindexFileReadOneRecord(RfileDesc, &TfindRecord)) 
+  {
+    RindexFreeOneTTfind(&TfindRecord);
+    RDBG("smbc: RindexFileExistAnyRecords exit 1\n");
+    return(1);
+  }
+  RDBG("smbc: RindexFileExistAnyRecords exit 0\n");
+  return(0);
+}
+
 int 
 RindexFileGetCount(int RfileDesc)
 {
   int Rt = 0;
-  off_t Rseek;
-  TTfind TfindRecord;
+  TTfind *TfindRecord = NULL;
   
-  RDBG("find-index-manage: RindexFileSetSeek start\n");
+  // read counter
+  RindexFileReadCounter(RfileDesc);
 
-#ifdef HAVE_DEBUG
-  Rseek = lseek(RfileDesc, 0, SEEK_CUR);
-  RDBG("find-index-manage: RindexFileSetSeek current lseek ");
-  RDBGi(Rseek);
-  RDBG("\n");
-#endif /* HAVE_DEBUG */
-
-  Rseek = lseek(RfileDesc, 0, SEEK_SET);
-  RDBG("find-index-manage: RindexFileSetSeek set lseek ");
-  RDBGi(Rseek);
-  RDBG("\n");
   while (RindexFileReadOneRecord(RfileDesc, &TfindRecord)) 
+  {
     Rt++;
+    RindexFreeOneTTfind(&TfindRecord);
+  }
   RDBG("find-index-manage: RindexFileSetSeek return ");
   RDBGi(Rt);
   RDBG(" records\n");
@@ -235,22 +287,23 @@ RindexFileTruncate(int RfileDesc, long int Rnr)
 {
   off_t Rseek;
 
-  RDBG("find-index-manage: RindexFileTruncate start\n");
   if (!RindexFileSetSeek(RfileDesc, Rnr)) 
-  {
-    RDBG("find-index-manage: RindexFileTruncate return failed\n");
     return(0);
-  }
   Rseek = lseek(RfileDesc, 0, SEEK_CUR);
   if (ftruncate(RfileDesc, Rseek) == 0) 
-  {
-    RDBG("find-index-manage: RindexFileTruncate return ok\n");
     return(1);
-  }
-  RDBG("find-index-manage: RindexFileTruncate return failed\n");
   return(0);
 }
 
+int
+RindexFileReadCounter(int RfileDesc)
+{
+  int Rreturn;
+
+  lseek(RfileDesc, 0, SEEK_SET);
+  RreadUnsignedInt(RfileDesc, &Rreturn);
+  return(Rreturn);
+}
 //--------------------------------------------------------------------------------
 
 int 
@@ -286,7 +339,7 @@ RfreeAllRecordFromIndexTable(TTindexTable **Ridx)
   {
     RidxTmp = (*Ridx);
     (*Ridx) = (*Ridx)->next;
-    free(RidxTmp);
+    Rfree(RidxTmp);
   }
   return(1);
 }
@@ -358,34 +411,54 @@ RgotoNextIndexTable(TTindexTable **Ridx)
 //--------------------------------------------------------------------------------
 
 int 
-RloadIndexFile(int Rfd, TTfind **RidxNet)
+RloadIndexFile(int Rfd, TTfind **RidxNet, int count, WINDOW *Rwin)
 {
-  TTfind Rfi;
+  TTfind *Rfi = NULL;
+  int RyIF = 0;
+  int RxIF = 0;
+  int RcountI = count;
+  char *RstrIF = NULL;
 
-  RDBG("find-index-manage: RloadIndexFile start\n");
   if (!RindexFileSetSeek(Rfd, 1)) 
   {
-    RDBG("find-index-manage: RloadIndexFile return failed\n");
     return(0);
   }
+
+  if (Rwin)
+    getmaxyx(Rwin, RyIF, RxIF);
   while (RindexFileReadOneRecord(Rfd, &Rfi)) 
   {
     if (*RidxNet) 
     {
       (*RidxNet)->next = Rmalloc(sizeof(TTfind));
-      memcpy((*RidxNet)->next, &Rfi, sizeof(TTfind)); 
-      (*RidxNet)->next->previous = (*RidxNet);
+      (*RidxNet)->next->previous = *RidxNet;
       *RidxNet = (*RidxNet)->next;
     }
     else 
     {
-      (*RidxNet) = Rmalloc(sizeof(TTfind));
-      memcpy((*RidxNet), &Rfi, sizeof(TTfind)); 
+      *RidxNet = Rmalloc(sizeof(TTfind));
       (*RidxNet)->previous = NULL;
     }
+    if (Rwin)
+    {
+      RcountI--;
+      RstrdupN(RstrIF, "");
+      Rintaddtoend(&RstrIF, trunc(((double)(count-RcountI)/(double)count)*100));
+      Rstraddtoend(&RstrIF, "%");
+      mvwhline(Rwin, 4, 1, 32, RxIF-2);
+      Rmvwprintw(Rwin, 4, RxIF/2-Rstrlen(RstrIF)/2, RstrIF);
+      wrefresh(Rwin);
+    }
+    (*RidxNet)->group = Rstrdup(Rfi->group);
+    (*RidxNet)->host = Rstrdup(Rfi->host);
+    (*RidxNet)->dir = Rstrdup(Rfi->dir);
+    (*RidxNet)->file = Rstrdup(Rfi->file);
+    (*RidxNet)->access_denied = Rstrdup(Rfi->access_denied);
+
     (*RidxNet)->next = NULL;
+    RindexFreeOneTTfind(&Rfi);
   }
-  RDBG("find-index-manage: RloadIndexFile finished\n");
+  Rfree(RstrIF);
   return(1);
 }
 
@@ -394,13 +467,21 @@ RfreeIndexFile(TTfind **RidxNet)
 {
   TTfind *Rtf;
 
+  RDBG("find-index-manage: RfreeIndexFile start\n");
   if (RindexNetSetSeek(RidxNet, 1)) 
   {
+    RDBG("find-index-manage: RfreeIndexFile 1\n");
     while (*RidxNet) 
     {
       Rtf = (*RidxNet);
       (*RidxNet) = (*RidxNet)->next;
-      free(Rtf);
+      Rfree(Rtf->group);
+      Rfree(Rtf->host);
+      Rfree(Rtf->dir);
+      Rfree(Rtf->file);
+      RDBG("find-index-manage: RfreeIndexFile Rtf->access_denied = |"); RDBG(Rtf->access_denied); RDBG("|\n");
+      Rfree(Rtf->access_denied);
+      Rfree(Rtf);
     }
   }
 }
@@ -431,7 +512,7 @@ RindexNetSetSeek(TTfind **RidxNet, int Rnr)
 }
 
 int 
-RindexNetReadOneRecord(TTfind **RidxNet, TTfind *RidxNetDst)
+RindexNetReadOneRecord(TTfind **RidxNet, TTfind **RidxNetDst)
 {
   RDBG("find-index-manage: RindexNetReadOneRecord start\n");
   if (!(*RidxNet)) 
@@ -439,12 +520,52 @@ RindexNetReadOneRecord(TTfind **RidxNet, TTfind *RidxNetDst)
     RDBG("find-index-manage: RindexNetReadOneRecord return failed\n");
     return(0);
   }
-  memcpy(RidxNetDst, (*RidxNet), sizeof(TTfind));
+  *RidxNetDst = Rmalloc(sizeof(TTfind));
+  (*RidxNetDst)->group = Rstrdup((*RidxNet)->group);
+  (*RidxNetDst)->host = Rstrdup((*RidxNet)->host);
+  (*RidxNetDst)->dir = Rstrdup((*RidxNet)->dir);
+  (*RidxNetDst)->file = Rstrdup((*RidxNet)->file);
+  (*RidxNetDst)->access_denied = Rstrdup((*RidxNet)->access_denied);
+  (*RidxNetDst)->next = NULL;
+  (*RidxNetDst)->previous = NULL;
+
   (*RidxNet) = (*RidxNet)->next;
   RDBG("find-index-manage: RindexNetReadOneRecord return ok\n");
   return(1);
 }
 
+int 
+RindexNetGoToNext(TTfind **RidxNet)
+{
+  if (!(*RidxNet)) 
+  {
+    return(0);
+  }
+  (*RidxNet) = (*RidxNet)->next;
+  return(1);
+}
+
+void 
+RindexFreeOneTTfind(TTfind **RidxNet)
+{
+  RDBG("find-index-manage: RindexFreeOneTTfind start\n");
+  if (*RidxNet)
+  {
+    if ((*RidxNet)->group) Rfree((*RidxNet)->group);
+    if ((*RidxNet)->host)  Rfree((*RidxNet)->host);
+    if ((*RidxNet)->dir)   Rfree((*RidxNet)->dir);
+    if ((*RidxNet)->file)  Rfree((*RidxNet)->file);
+    RDBG("find-index-manage: (*RidxNet)->access_denied = |"); RDBG((*RidxNet)->access_denied); RDBG("|"); 
+    RDBGi(Rstrlen((*RidxNet)->access_denied)); RDBG("|\n");
+
+    if ((*RidxNet)->access_denied) Rfree((*RidxNet)->access_denied);
+    RDBG("find-index-manage: RindexFreeOneTTfind 1\n");
+    Rfree(*RidxNet);
+    RDBG("find-index-manage: RindexFreeOneTTfind 2\n");
+  }
+  RDBG("find-index-manage: RindexFreeOneTTfind end\n");
+}
+
 //------------------------------------------------
 
 int 
@@ -482,8 +603,8 @@ RFreeHostsTable(TThostsTable **RhostsTable)
    {
      RhostsTableTym = (*RhostsTable);
      (*RhostsTable) = (*RhostsTable)->next;
-     free(RhostsTableTym->name);
-     free(RhostsTableTym);
+     Rfree(RhostsTableTym->name);
+     Rfree(RhostsTableTym);
    }
    return(1);
 }
@@ -491,20 +612,13 @@ RFreeHostsTable(TThostsTable **RhostsTable)
 int 
 RFindHostInToHostsTable(TThostsTable *RhostsTable, char *Rstr)
 {
-  //RDBG("find-index-manage: RFindHostInToHostsTable start\n");
   while (RhostsTable) 
   {
-    //RDBG("find-index-manage: RFindHostInToHostsTable compare : ");
-    //RDBG(RhostsTable->name); RDBG("  "); RDBG(Rstr); RDBG("\n");
     if (RstrCmp(RhostsTable->name, Rstr)) 
-    {
-      //RDBG("find-index-manage: RFindHostInToHostsTable return 1\n");
       return(1);
-    }
     else 
       RhostsTable = RhostsTable->next;
   }
-  //RDBG("find-index-manage: RFindHostInToHostsTable return 0\n");
   return(0);
 }
 
