@@ -4,33 +4,13 @@
 
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
-       jabber: rafim@jabber.org
+       jabber: rafim@jabber.airm.net
     home page: http://smbc.airm.net
-  
-    last update: 2004-03-10
 */
 
+#include <curses.h>
 #include "consts.h"
-
-typedef struct Tfind { 
-  char group[RMAXGHLEN];
-  char host[RMAXGHLEN];
-  char dir[2000];
-  char file[1000];
-  struct Tfind *next;
-  struct Tfind *previous;
-} TTfind; 
-
-typedef struct TindexTable {
-  int number;
-  struct TindexTable *next;
-  struct TindexTable *previous;
-} TTindexTable;
-
-typedef struct ThostsTable {
-  char *name;
-  struct ThostsTable *next;
-} TThostsTable;
+#include "rtypedef.h"
 
 int RmakeCopyFileWithPID(char *Rdst, char *Rsrc);
 
@@ -39,11 +19,13 @@ int RindexFileOpen(char *RpathToFile, int *RfileDesc);
 int RindexFileCreate(char *RpathToFile, int *RfileDesc);
 void RindexFileClose(int *RfileDesc);
 
-int RindexFileReadOneRecord(int RfileDesc, TTfind *TfindRecord);
+int RindexFileReadOneRecord(int RfileDesc, TTfind **TfindRecord);
 int RindexFileWriteOneRecord(int RfileDesc, TTfind *TfindRecord);
 int RindexFileSetSeek(int RfileDesc, long int Rnr);
+int RindexFileExistAnyRecords(int RfileDesc);
 int RindexFileGetCount(int RfileDesc);
 int RindexFileTruncate(int RfileDesc, long int Rnr);
+int RindexFileReadCounter(int RfileDesc);
 
 //-----------------------------------------------------------------
 
@@ -57,11 +39,13 @@ int RgotoNextIndexTable(TTindexTable **Ridx);
 
 //-----------------------------------------------------------------
 
-int RloadIndexFile(int Rfd, TTfind **RidxNet);
+int RloadIndexFile(int Rfd, TTfind **RidxNet, int count, WINDOW *Rwin);
 void RfreeIndexFile(TTfind **RidxNet);
 
 int RindexNetSetSeek(TTfind **RidxNet, int Rnr);
-int RindexNetReadOneRecord(TTfind **RidxNet, TTfind *RidxNetDst);
+int RindexNetReadOneRecord(TTfind **RidxNet, TTfind **RidxNetDst);
+int RindexNetGoToNext(TTfind **RidxNet);
+void RindexFreeOneTTfind(TTfind **RidxNet);
 
 //-----------------------------------------------------------------
 
