@@ -6,8 +6,6 @@
         email: <rafim@data.pl>
        jabber: rafim@jabber.org
     home page: http://smbc.airm.net
-
-  last update: 2004-08-08
 */
 // -------------------------------------------------------------------
 #define _GNU_SOURCE
@@ -63,7 +61,7 @@ itoa(char *str, int strLen, int n)
   void itoaAddChar(char Rch)
   {
     asprintf(&RstrTT, "%s%c", RstrT?RstrT:"", Rch);
-    free(RstrT);
+    Rfree(RstrT);
     RstrT = RstrTT;
   }
 
@@ -83,6 +81,14 @@ itoa(char *str, int strLen, int n)
   str[sign+1] = 0;
 }  
 
+void
+itoaMalloc(char **str, int strLen, int n)
+{
+  Rfree(*str);
+  *str = Rmalloc(strLen);
+  itoa(*str, strLen, n);
+}
+
 int 
 readline(register int fd, register char *ptr, register int maxlen)
 {
@@ -425,7 +431,7 @@ refreshTxtInWin(WINDOW *win, int y, int x, char *buf, int winSize, int startidx,
   wattroff(win, attr);
   if (colorPair != -1) 
     wattroff(win, COLOR_PAIR(colorPair));
-  free(str);
+  Rfree(str);
 }
 
 //  0 <= xCursor <= strlen(buf)
@@ -470,7 +476,7 @@ refreshTxtInWinCursor(WINDOW *win, int y, int x, char *buf, int winSize, int sta
   RDBG("fnet refreshTxtInWinCursor 1: Rstr = \""); RDBG(Rstr); RDBG("\"\n");
   mvwprintw(win, y, x, Rstr);
   Rprinted = strlen(Rstr);
-  free(Rstr);
+  Rfree(Rstr);
    
   // char in curor position
   wattron(win, A_REVERSE);
@@ -495,7 +501,7 @@ refreshTxtInWinCursor(WINDOW *win, int y, int x, char *buf, int winSize, int sta
   }
   RDBG("fnet refreshTxtInWinCursor 29: Rstr = \""); RDBG(Rstr); RDBG("\"\n");
   mvwprintw(win, y, x+Rprinted, Rstr);
-  free(Rstr);
+  Rfree(Rstr);
   wattroff(win, A_REVERSE);
   Rprinted++;
 
@@ -509,16 +515,17 @@ refreshTxtInWinCursor(WINDOW *win, int y, int x, char *buf, int winSize, int sta
        Rstr[winSize-Rprinted] = 0;
     RDBG("fnet refreshTxtInWinCursor 3: Rstr = \""); RDBG(Rstr); RDBG("\"\n");
     mvwprintw(win, y, x+Rprinted, Rstr);
-    free(Rstr);
+    Rfree(Rstr);
   }
 
   if (colorPair != -1) 
     wattroff(win, COLOR_PAIR(colorPair));
-  free(Rbuf);
+  Rfree(Rbuf);
 }
 
 int 
-readlineWaitForOneChar(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair, int *ctrlp, int *startidx, int *wxx) 
+readlineWaitForOneChar(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, 
+                       int colorPair, int *ctrlp, int *startidx, int *wxx) 
 {
   int Rfirst = 1;
   int Rt = 0;
@@ -530,7 +537,9 @@ readlineWaitForOneChar(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int
 
 // if first = 2 readlineOneCharNoDelay is in password mode
 int 
-readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair, int *ctrlp, int Rnodelay, int *startidx, int *wxx, int *first)
+readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, 
+                       int colorPair, int *ctrlp, int Rnodelay, int *startidx, int *wxx, 
+                       int *first)
 {
   int klawisz = 0;
   int esc, Ri;
@@ -584,7 +593,9 @@ readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int
              { 
                (*startidx)--;
                (*wxx)--;
-             } else (*wxx)--;
+             } 
+             else 
+               (*wxx)--;
            };
            refreshTxtInWinCursor(win,wy,wx,buf, winSize, *startidx, colorPair, *wxx, RpassMode);
         }
@@ -661,7 +672,8 @@ readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int
          klawisz == 188 || klawisz == 172 ||   // ,
          klawisz == 230 || klawisz == 198 ||   // ,
          klawisz == 241 || klawisz == 209 ||   // ,
-         klawisz == '.' || klawisz == ',')) && 
+         klawisz == '.' || klawisz == ',' ||
+         klawisz == '-')) && 
         (Rbufl+1 < sizebuf)) {
       if ((*wxx) == Rbufl) 
       {
@@ -715,10 +727,8 @@ RgetFileFromTwoDirs(char **RfileName, char *RdirBig, char *RdirSmall)
   int Rlen, RlB, RlS, Rlo;
   int Rs = 0;
 
-  RDBG("fnet: RgetFileFromTwoDirs start: RdirBig = "); RDBG(RdirBig); 
-  RDBG("     RdirSmall = "); RDBG(RdirSmall); RDBG("\n");
-  RlB = strlen(RdirBig);
-  RlS = strlen(RdirSmall);
+  RlB = Rstrlen(RdirBig);
+  RlS = Rstrlen(RdirSmall);
   if ((RdirBig != NULL) &&
       (RdirSmall != NULL) &&
       (RlB > RlS)) 
@@ -726,14 +736,20 @@ RgetFileFromTwoDirs(char **RfileName, char *RdirBig, char *RdirSmall)
     Rlen = RlB - RlS + 1;
     Rstr = Rmalloc(Rlen);
     memcpy(Rstr, RdirBig+RlS, Rlen);
+    Rstr[Rlen] = 0;
+
     if (Rstr[0] == '/') 
       Rs = 1;
-    if (Rstr[Rlen-2] == '/') 
-      Rstr[Rlen-2] = 0;
-    Rlo = strlen(Rstr+Rs)+1;
-    *RfileName = Rmalloc(Rlo);
-    memcpy(*RfileName, Rstr+Rs, Rlo);
-    RDBG("fnet: RgetFileFromTwoDirs return : "); RDBG(*RfileName); RDBG("\n");
+
+    Rlo = strlen(Rstr);
+    if (Rlo > 1)
+    if (Rstr[Rlo-1] == '/')
+      RtruncateStr(&Rstr, Rlo-1);
+
+    Rlo = strlen(Rstr)+1;
+
+    RstrdupN(*RfileName, Rstr+Rs);
+    Rfree(Rstr);
   }
   else
     *RfileName = NULL;
@@ -748,9 +764,411 @@ Rmalloc(size_t Isize)
   if (Rret == NULL) 
   {
     RDBG("fnet: Rmalloc malloc failed\n");
-    kill(getpid(), SIGSEGV);
+    kill(0, SIGTERM);
     return(NULL);
   }
   return(Rret);
 }
 
+char *
+Rstrcpy(char *dest, int destLen, const char *src, int srcLen)
+{
+  int CsrcLen = strlen(src);
+
+  if (srcLen > -1)
+  {
+    if (CsrcLen > srcLen)
+      return(NULL);
+  }
+  if (destLen > -1)
+  {
+  if (CsrcLen > destLen)
+    return(NULL);
+  }
+  return(strncpy(dest, src, CsrcLen+1));
+}
+
+int
+Rasprintf(char **strp, const char *fmt)
+{
+  int Ri;
+
+  RDBG("fnet: Rasprintf start\n");
+  if (fmt)
+  {
+    RDBG("fnet: Rasprintf 1\n");
+    Ri = strlen(fmt)+1;
+    RDBG("fnet: Rasprintf 2\n");
+  }
+  else
+  {
+    RDBG("fnet: Rasprintf 3\n");
+    return(-1);
+  }
+
+  *strp = Rmalloc(Ri);
+  if (*strp == NULL)
+  {
+    kill(0, SIGTERM);
+  }
+  memcpy(*strp, fmt, Ri);
+  RDBG("fnet: Rasprintf end\n");
+  return(Ri);
+}
+
+int
+Rstraddtoend(char **strp, const char *fmt)
+{
+  int Ra;
+  int Rb;
+  char *Ri;
+
+  if (*strp)
+    Ra = strlen(*strp);
+  else
+    Ra = 0;
+  if (fmt)
+    Rb = strlen(fmt);
+  else
+    Rb = 0;
+
+  Ri = Rmalloc(Ra+Rb+1);
+
+  if (Ri == NULL)
+    kill(0, SIGTERM);
+  memcpy(Ri, *strp, Ra);
+  memcpy(Ri+Ra, fmt, Rb+1);
+  Rfree(*strp);
+  *strp = Ri;
+  return(strlen(Ri)+1);
+}
+
+int
+Rcharaddtoend(char **strp, const char fmt)
+{
+  int Ra;
+  char *Ri;
+
+  if (*strp)
+    Ra = strlen(*strp);
+  else
+    Ra = 0;
+
+  Ri = Rmalloc(Ra+2);
+
+  if (Ri == NULL)
+    kill(0, SIGTERM);
+  memcpy(Ri, *strp, Ra);
+  Ri[Ra] = fmt;
+  Ri[Ra+1] = 0;
+  if (*strp)
+    free(*strp);
+  *strp = Ri;
+  return(strlen(Ri)+1);
+}
+
+int
+Rintaddtoend(char **strp, int fmt)
+{
+  char *Ri = NULL;
+
+  asprintf(&Ri, "%i", fmt);
+
+  if (Ri == NULL)
+    kill(0, SIGTERM);
+  Rstraddtoend(strp, Ri);
+  free(Ri);
+  return(strlen(Ri)+1);
+}
+
+int
+Rmvwprintw(WINDOW *win, int y, int x, const char *fmt)
+{
+  int Ri;
+  char *Rc1;
+  char *Rc2;
+  char Rchanged = 1;
+  int Rc2start = 0;
+
+  void
+  RmvwprintwAddPercent()
+  {
+    char *Rt1 = NULL;
+    int Rti = 0;
+
+    Rt1 = malloc(strlen(Rc1)+2);
+    if (Rt1 == NULL)
+      kill(0, SIGTERM);
+    Rti = Rc2-Rc1+1;
+    memcpy(Rt1, Rc1, Rti);
+    Rt1[Rti] = '%';
+    memcpy(Rt1+Rti+1, Rc2+1, strlen(Rc2));  // strlen((Rc2+1)+1) == strlen(Rc2);
+    Rfree(Rc1);
+    Rc1 = Rt1;
+    Rc2start = Rti+1;
+    Rchanged = 1;
+  }
+
+  if (fmt == NULL)
+    return(0);
+
+  Rasprintf(&Rc1, fmt);
+
+  while (Rchanged)
+  {
+    Rchanged = 0;
+    if (Rc1 == NULL)
+      kill(0, SIGTERM);
+    Rc2 = Rc1+Rc2start;
+    while (Rc2[0] && !Rchanged)
+    {
+      if (Rc2[0] == '%')
+        RmvwprintwAddPercent();
+      Rc2++;
+    }
+  }
+  RDBG("fnet: RmvwprintwAddPercent fmt = |"); RDBG((char *)fmt); RDBG("|\n");
+  RDBG("fnet: RmvwprintwAddPercent Rc1 = |"); RDBG(Rc1); RDBG("|\n");
+  mvwprintw(win, y, x, Rc1);
+  Ri = strlen(Rc1);
+  Rfree(Rc1);
+  RDBG("fnet: RmvwprintwAddPercent end\n");
+  return(Ri);
+}
+
+int
+RtruncateStr(char **Rstr, int Rpos)
+{
+  char *Rst = NULL;
+
+  RDBG("fnet: RtruncateStr 1\n");
+  if (Rpos > strlen(*Rstr))
+    kill(0, SIGTERM);
+  RDBG("fnet: RtruncateStr 2\n");
+  Rst = Rmalloc(Rpos+1);
+  memcpy(Rst, *Rstr, Rpos);
+  RDBG("fnet: RtruncateStr 3\n");
+  Rst[Rpos] = 0;
+  Rfree(*Rstr);
+  *Rstr = Rst;
+  RDBG("fnet: RtruncateStr 10\n");
+  return(strlen(*Rstr));
+}
+
+char *
+Rstrdup(char *Rstr)
+{
+  char *Rout;
+
+  if (Rstr == NULL)
+    return(NULL);
+  Rout = strdup(Rstr);
+
+  if ((Rout == NULL) && (Rstr != NULL))
+    kill(0, SIGTERM);
+  return(Rout);
+}
+
+int
+RstrCmp(char *src, char *dst) 
+{
+  if ((src == NULL) || (dst == NULL))
+    kill(0, SIGTERM);
+  return(!strcmp(src, dst));
+}
+
+ssize_t 
+RwriteUnsignedInt(int fd, unsigned int buf)
+{
+  int Ri;
+  int count = sizeof(unsigned int);
+
+  if (fd < 0)
+    kill(0, SIGTERM);
+  Ri = write(fd, &buf, count);
+  if (Ri != count)
+    kill(0, SIGTERM);
+  return(Ri);
+}
+
+ssize_t 
+RwriteStr(int fd, const char *buf)
+{
+  ssize_t Ri;
+  ssize_t count = strlen(buf)+1;
+
+  if (fd < 0)
+    kill(0, SIGTERM);
+  if (buf == NULL)
+  {
+    count = 1;
+    Ri = write(fd, "", count);
+  }
+  else
+    Ri = write(fd, buf, count);
+  if (Ri != count)
+    kill(0, SIGTERM);
+  return(Ri);
+}
+
+ssize_t 
+RwriteChar(int fd, const char buf)
+{
+  ssize_t Ri;
+  ssize_t count = sizeof(char);
+
+  if (fd < 0)
+    kill(0, SIGTERM);
+  Ri = write(fd, &buf, count);
+  if (Ri != count)
+    kill(0, SIGTERM);
+  return(Ri);
+}
+
+ssize_t 
+RwriteTime_t(int fd, time_t buf)
+{
+  ssize_t Ri;
+  ssize_t count = sizeof(time_t);
+
+  if (fd < 0)
+    kill(0, SIGTERM);
+  Ri = write(fd, &buf, count);
+  if (Ri != count)
+    kill(0, SIGTERM);
+  return(Ri);
+}
+
+size_t
+RreadStr(int fd, char **buf)
+{
+  char Rch;
+
+  if (*buf)
+    Rfree(*buf);
+  while (read(fd, &Rch, 1) == 1)
+  {
+    Rcharaddtoend(buf, Rch);
+    if (Rch == 0)
+      return(strlen(*buf));
+  }
+  Rfree(*buf);
+  return(-1);
+}
+
+int
+RreadUnsignedInt(int fd, unsigned int *buf)
+{
+  int Ri = sizeof(unsigned int);
+
+  if (read(fd, buf, Ri) == Ri)
+    return(Ri);
+  return(-1);
+}
+
+int
+RreadChar(int fd, char *buf)
+{
+  int Ri = sizeof(char);
+
+  if (read(fd, buf, Ri) == Ri)
+    return(Ri);
+  return(-1);
+}
+
+time_t
+RreadTime_t(int fd, time_t *buf)
+{
+  int Ri = sizeof(time_t);
+
+  if (read(fd, buf, Ri) == Ri)
+    return(Ri);
+  return(-1);
+}
+
+size_t
+Rstrlen(const char *s)
+{
+  if (s == NULL)
+    return(0);
+  else
+    return(strlen(s));
+}
+
+void
+RchdirUp(char **Rstr)
+{
+  int RicU;
+  char *RstrT = NULL;
+
+  if (Rstr == NULL)
+    kill(0, SIGTERM);
+  if (*Rstr == NULL)
+    kill(0, SIGTERM);
+
+  RicU = strlen(*Rstr);
+  if (RicU == 0)
+    return;
+
+  RstrT = Rstrdup(*Rstr);
+  if (RstrT[RicU-1] == '/')
+  {
+    RtruncateStr(&RstrT, RicU-1);
+  }
+
+  while(strlen(RstrT) > 0)
+  {
+    RicU = strlen(RstrT);
+    if (RstrT[RicU-1] != '/')
+      RtruncateStr(&RstrT, RicU-1);
+    else
+    {
+      RstrdupN(*Rstr, RstrT);
+      return;
+    }
+  }
+  RstrdupN(*Rstr, RstrT);
+}
+
+void
+RparsingDir(char **Rstr)
+{
+  int Ri = 0;
+  char *RstrT = NULL;
+
+  if (*Rstr == NULL)
+    kill(0, SIGTERM);
+
+  Ri = Rstrlen(*Rstr);
+
+  if (*Rstr[0] == '/')
+    RstrdupN(RstrT, *Rstr+1)
+  else
+    RstrdupN(RstrT, *Rstr);
+  
+  if (RstrT[Ri] != '/')
+    Rcharaddtoend(&RstrT, '/');
+
+  Rfree(*Rstr);
+  *Rstr = RstrT;
+}
+
+int
+RmakeCopyFileFromPIDtoPID(int Rdst, int Rsrc)
+{
+#define READBF 1024
+
+  char Rdata[READBF];
+  int Rread;
+  int Rwrite;
+
+  if ((Rdst <= 0) || (Rsrc <= 0))
+    kill(0, SIGHUP);
+  while ((Rread = read(Rsrc, &Rdata, READBF)))
+  {
+    Rwrite = write(Rdst, &Rdata, Rread);
+    if (Rread != Rwrite)
+      kill(0, SIGHUP);
+  }
+  return(1);
+}
