@@ -4,14 +4,22 @@
 
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
-       jabber: rafim@jabber.org
-    home page: http://www.air.rzeszow.pl/smbc
-  
-    last update: 2004-01-25
+       jabber: rafim@jabber.airm.net
+    home page: http://smbc.airm.net
 */
 
 #include "../config.h"
 
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else  /* not HAVE_STRING_H */
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif /* HAVE_STRINGS_H */
+#endif /* not HAVE_STRING_H */
+
+#include <libsmbclient.h>
+
 #define RstrCmp(src, dst) (!strcmp(src, dst))
 
 #ifdef HAVE_SMBCCTX
@@ -33,5 +41,6 @@ int Rsmbc_open(const char *furl, int flags, mode_t mode);
 int Rsmbc_closedir(int Rfd);
 int Rsmbc_close(int Rfd);
 int Rsmbc_opendir(char *Rstr);
-struct smbc_dirent *Rsmbc_readdir(int Rfd);
+//struct smbc_dirent *Rsmbc_readdir(int Rfd);
+int Rsmbc_readdir(int Rfd, struct smbc_dirent **Rdirent);
 
