@@ -4,10 +4,8 @@
 
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
-       jabber: rafim@jabber.org
-    home page: http://www.air.rzeszow.pl/smbc
-  
-    last update: 2004-05-15
+       jabber: rafim@jabber.airm.net
+    home page: http://smbc.airm.net
 */
 
 void RsendWinpopup(char *RpathToSmbclient, char *Rrcp, char *Rtxt);
